# Suntranslator

A tool used to translate text into the Sun language

![GitHub last commit](https://img.shields.io/github/last-commit/cjhead/suntranslator)
![GitHub](https://img.shields.io/github/license/cjhead/suntranslator)
![GitHub issues](https://img.shields.io/github/issues/cjhead/suntranslator)
![GitHub pull requests](https://img.shields.io/github/issues-pr/cjhead/suntranslator)

![GitHub Repo stars](https://img.shields.io/github/stars/cjhead/suntranslator?style=social)
![GitHub forks](https://img.shields.io/github/forks/cjhead/suntranslator?style=social)
![GitHub watchers](https://img.shields.io/github/watchers/cjhead/suntranslator?style=social)

## Table of Contents
- [Install](#install)
- [Usage](#usage)

## Dependencies
To view the translated text within the program itself, you will need to download the Keyman program and install the Sun keymap. Download instructions for Keyman can be found at the bottom of the page [here](https://keyman.com/) and instructions for installing custom keymaps [here](https://help.keyman.com/products/linux/current-version/start/installing-keyboard)(scroll down to the section titled "Install Local .kmp keyboard package").

You do not need to install this font in order to save your output in the Sun language.

## Install
Suntranslator is a python package which relies on the python interpreter. The latest release of python can be downloaded from [here](https://www.python.org/downloads/).
```bash
$ python3 -m pip install suntranslator
```

## Usage
Open a terminal and call the program
```bash
$ suntranslator
```
